@@ -407,7 +407,7 @@ void LockScreen::onAlarmDialogStatusChanged(QDBusMessage msg)
     m_isDialogActive = status == 5;
     if (m_isDialogActive){
         hide();
-    }else if (m_tklockState == MCE_TK_LOCKED && m_displayState == MCE_DISPLAY_OFF_STRING)
+    }else if (m_tklockState == MCE_TK_LOCKED) // && m_displayState == MCE_DISPLAY_OFF_STRING)
         show();
 }
 
