@@ -110,10 +110,10 @@ void LsBattery::bmePropertyModifiedSlot(QDBusMessage)
         float vdesign = 0;
         bool charging = false;
 
-        foreach (QString line, lines){
-            line = line.trimmed();
+        foreach (const QString line, lines){
+            QString trimmed = line.trimmed();
 
-            QStringList e = line.split("=", QString::SkipEmptyParts);
+            QStringList e = trimmed.split("=", QString::SkipEmptyParts);
             if (e.count() > 1){
                 QString name = e.at(0).trimmed();
                 QString value = e.at(1).trimmed();
