@@ -42,12 +42,15 @@ private:
     PercSource m_PercSource;
     bool m_IsCharging;
     float m_Percentage;
-    QList<QPixmap> m_Images;
-    QPixmap m_ChargingImage;
+    QPixmap m_Image;
+    QStringList m_Images;
+    QString m_CurrImage;
+    QString m_ChargingImage;
     QFont m_PercFont;
     QColor m_PercColor;
 
     float GetValue(QString file);
+    void setImage();
 
 private slots:
 #ifdef Q_WS_MAEMO_5
