@@ -28,19 +28,12 @@ void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem* o
                             QWidget*)
 {
     painter->setClipRect(option->exposedRect);
-    QString title = m_Metadata.value(SYSTEM_PLAYER_SONG_TITLE).toString();
-    if (title.isEmpty())
-        title = tr("Unknown title");
 
     QFontMetrics tfm(m_TitleFont);
-    title = tfm.elidedText(title, Qt::ElideRight, option->exposedRect.width());
-
-    QString artist = m_Metadata.value(SYSTEM_PLAYER_SONG_ARTIST).toString();
-    if (artist.isEmpty())
-        artist = tr("Unknown artist");
+    QString title = tfm.elidedText(m_Title, Qt::ElideRight, option->exposedRect.width());
 
     QFontMetrics afm(m_ArtistFont);
-    artist = afm.elidedText(artist, Qt::ElideRight, option->exposedRect.width());
+    QString artist = afm.elidedText(m_Artist, Qt::ElideRight, option->exposedRect.width());
 
     QRectF rect(boundingRect());
 
@@ -87,6 +80,17 @@ void LsMediaMetadata::startUpdate()
 void LsMediaMetadata::onMetadataChanged(QMap<QString,QVariant> data)
 {
     qDebug() << "Metadata changed";
-    m_Metadata = data;
-    update();
+    QString artist = data.value(SYSTEM_PLAYER_SONG_ARTIST).toString();
+    if (artist.isEmpty())
+        artist = tr("Unknown artist");
+
+    QString title = data.value(SYSTEM_PLAYER_SONG_TITLE).toString();
+    if (title.isEmpty())
+        title = tr("Unknown title");
+
+    if (artist != m_Artist || title != m_Title){
+        m_Artist = artist;
+        m_Title = title;
+        update();
+    }
 }
