@@ -34,7 +34,10 @@ public:
     void startUpdate();
 
 private:
-    QMap<QString,QVariant> m_Metadata;
+    QString m_Title;
+    QString m_Artist;
+    QString m_Album;
+
     SystemPlayer* m_Player;
 
     int m_Alignment;
