@@ -23,8 +23,9 @@
 #include <QSqlError>
 #include "lswidget.h"
 
-class LsNotification : public LsWidget
+class LsNotification : public QObject, public LsWidget
 {
+    Q_OBJECT
 public:
     enum Notifications
     {
@@ -46,11 +47,14 @@ private:
     QSqlDatabase m_Db;
     Notifications m_Type;
     QPixmap m_Icon;
+    Qt::AlignmentFlag m_Alignment;
+    QString m_BaseText;
     QString m_Text;
     QFont m_Font;
     QColor m_Color;
 
 
+private slots:
     void updateNotification();
 };
 
