@@ -23,9 +23,10 @@ LsRect::LsRect(QString name) :
     applySettings();
 }
 
-void LsRect::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
+void LsRect::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
                    QWidget*)
 {
+    painter->setClipRect(option->exposedRect);
     painter->setBrush(m_Color);
     painter->setPen(Qt::NoPen);
     painter->drawRoundedRect(boundingRect(), m_Radius, m_Radius);
