@@ -17,6 +17,7 @@
 //    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "lsunlockbutton.h"
 #include <QApplication>
+#include "lockscreen.h"
 
 LsUnlockButton::LsUnlockButton(QString name) :
         LsButton(name.isEmpty() ? "UnlockButton": name)
@@ -64,6 +65,9 @@ void LsUnlockButton::onTimer()
         QDBusInterface lockScreen("com.nokia.mce", "/com/nokia/mce/request", "com.nokia.mce.request", QDBusConnection::systemBus(), this);
         lockScreen.call("req_tklock_mode_change", "unlocked");
     }
+    if (LockScreen::Debug)
+        qApp->quit();
+
 #else
     if (isUnderMouse())
         qApp->quit();
