@@ -75,7 +75,7 @@ void LsWifi::netStateChanged(QString, QString type, QString state, QString)
 void LsWifi::startUpdate()
 {
 #ifdef Q_WS_MAEMO_5
-    //if (!LockScreen::Debug)
+    if (!LockScreen::Debug)
         getNetworkState();
     QDBusConnection::systemBus().connect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
                                          "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
